powered by
Estimates the number of communities under block models by using the spectral properties of network Beth-Hessian matrix with moment correction.
BHMC.estimate(A, K.max = 15)
adjacency matrix of the network
the maximum possible number of communities to check
A list of result
Estimated K
eigenvalues of the Beth-Hessian matrix
Note that the method cannot distinguish SBM and DCSBM. But it works under either model.
C. M. Le and E. Levina. Estimating the number of communities in networks by spectral methods. arXiv preprint arXiv:1507.00827, 2015.
LRBIC,ECV.Block, NCV.select
LRBIC
ECV.Block
NCV.select
# NOT RUN { dt <- BlockModel.Gen(30,300,K=3,beta=0.2,rho=0.9,simple=FALSE,power=TRUE) A <- dt$A bhmc <- BHMC.estimate(A,15) bhmc # }
Run the code above in your browser using DataLab