Learn R Programming

randnet (version 0.4)

ConsensusClust: clusters nodes by concensus (majority voting) initialized by regularized spectral clustering

Description

community detection by concensus (majority voting) initialized by regularized spectral clustering

Usage

ConsensusClust(A,K,tau=0.25,lap=TRUE)

Arguments

A

adjacency matrix

K

number of communities

tau

reguarlization parameter for regularized spectral clustering. Default value is 0.25. Typically set between 0 and 1. If tau=0, no regularization is applied.

lap

indicator. If TRUE, the Laplacian matrix for initializing clustering. If FALSE, the adjacency matrix will be used.

Value

cluster labels

Details

Community detection algorithm by majority voting algorithm of Gao et. al. (2016). When initialized by regularized spectral clustering, it is shown that the clustering accuracy of this algorithm gives minimax rate under the SBM. However, it can slow compared with spectral clustering.

References

Gao, C.; Ma, Z.; Zhang, A. Y. & Zhou, H. H. Achieving optimal misclassification proportion in stochastic block models The Journal of Machine Learning Research, JMLR. org, 2017, 18, 1980-2024

See Also

reg.SP

Examples

Run this code
# NOT RUN {

dt <- BlockModel.Gen(15,300,K=3,beta=0.2,rho=0)


A <- dt$A


#cc <- ConsensusClust(A,K=3,lap=TRUE)
# takes about 25 seconds

#NMI(cc,dt$g)


# }

Run the code above in your browser using DataLab