Learn R Programming

randnet (version 0.4)

RDPG.Gen: generates random networks from random dot product graph model

Description

generates random networks from random dot product graph model

Usage

RDPG.Gen(n, K, directed = TRUE, avg.d = NULL)

Arguments

n

size of the network

K

dimension of latent space

directed

whether the network is directed or not

avg.d

average node degree of the network (in expectation)

Value

a list of

A

the adjacency matrix

P

the probability matrix

%% ...

Details

The network is generated according to special formulation mentioned in ECV paper.

References

S. J. Young and E. R. Scheinerman. Random dot product graph models for social networks. In International Workshop on Algorithms and Models for the Web-Graph, pages 138-149. Springer, 2007. T. Li, E. Levina, and J. Zhu. Network cross-validation by edge sampling. Biometrika, 107(2), pp.257-276, 2020.

Examples

Run this code
# NOT RUN {
dt <- RDPG.Gen(n=600,K=2,directed=TRUE)

A <- dt$A

# }

Run the code above in your browser using DataLab