RightSC: clusters nodes in a directed network by regularized spectral clustering on right singular vectors
Description
community detection by regularized spectral clustering on right singular vectors
Usage
RightSC(A, K, normal = FALSE)
Arguments
A
adjacency matrix of a directed adjacecy matrix
K
number of communities
normal
indicator. If TRUE, normalization of singular vector rows will be applied, similar to the spectral spherical clustering.
Value
a list of
cluster
cluster labels
loss
the loss of Kmeans algorithm
%% ...
Details
This is essentially the spectral clustering applied on right singular vectors. It can be used to handle directed networks where Aij = 1 if and only if i -> j, and the edges tend to have a missing issue specifically depending on the sender i. More details can be found in Li et. al. (2020).
References
T. Li, E. Levina, and J. Zhu. Community models for networks observed through edge nominations. arXiv preprint arXiv:2008.03652 (2020).